close all

% importing of the previously defined fitting parameters
Cr = FitFun.b3;
dCr = FitFun.c3;


manualPhaseDiagram = [0,20,50,100,200,300,400,500,600,700,800,900,1000;   % pressure values in mbar
    1,0.92,0.83,0.19,0.43,0.53,0.47,0.38,0.25,0.15,0.16,0.14,0.13;        % population of manually classified others
    0,0,0,0.01,0.05,0.25,0.36,0.54,0.7,0.85,0.84,0.85,0.87;               % population of manually classified slippers
    0,0.08,0.17,0.8,0.52,0.21,0.17,0.08,0.05,0,0,0.01,0];                 % population of manually classified croissants


% velocity values according to the applied pressure drop (evaluated by
% another routine)
velocities = [0,0.135124,0.434646,0.983940,2.072512,3.160878,4.193231,5.182509,6.056290,7.262354,8.188598,9.314515,10.550081];

pressuresMan = manualPhaseDiagram(1,:);
othersMan = manualPhaseDiagram(2,:);
slippersMan = manualPhaseDiagram(3,:);
croissantsMan = manualPhaseDiagram(4,:);

% Please specify here the location of the respective folders where
% croissants, slippers and others shall be stored
targetCroissant = 'C:\Users\...';
targetSlipper = 'C:\Users\...';
targetOther =  'C:\Users\...';


path = 'C:\Users\...';

content = dir(path);

foldernames = {};

for idx = 1:numel(content)
    name = content(idx).name;
    foldernames{end+1} = name;
end

foldernames = foldernames(3:end);

sigmaEnd = 2.5;

fig = figure;
set(fig, 'Units', 'centimeters', 'Position', [25, 3, 19, 20]);
set(fig, 'defaultAxesTickLabelInterpreter','latex');
set(fig, 'defaultLegendInterpreter','latex');
set(fig, 'defaultTextInterpreter','latex');
fig.Renderer='Painters';


collectionImgsNNans = {};
txtLeft = [string('(a)'),string('(c)'),string('(e)')];
txtRight = [string('(b)'),string('(d)'),string('(f)')];

ndxMax = 3;
for ndx = 1:1:ndxMax
    
    sigma = ndx;
    
    % thresholds from standard deviations
    croissantTh = [Cr-sigma*dCr,Cr+sigma*dCr;];
    slipperTh = [Sl-sigma*dSl,Sl+sigma*dSl];
    
    if sigma == ndxMax
        croissantTh = [116.8-35.5,116.8+35.5];
        slipperTh = [-116.6-28.5,-116.6+28.5];
    end
    
    figure(fig)
    subplot(ndxMax,2,2*(ndx-1)+1)
    
    [N,c] = hist(collectionVals,100);
    plot(c,N,'Color',[0.5,0.5,0.5])
    hold on
    plot(c(1):0.001:c(end),feval(FitFun,c(1):0.001:c(end)),'Color','black')
    grid on
    
    
    if ndx == 3
        txt = strcat(txtLeft(ndx),' adapted threshold ranges');
    else
        txt = strcat(txtLeft(ndx),' threshold = ',num2str(sigma),'$$\sigma$$');
    end
    text(-180,900,txt,'HorizontalAlignment','left')
    
    
    axes = gca;
    set(axes.YLabel,'Interpreter','latex');
    set(axes.XLabel,'Interpreter','latex');
    xlabel('CNN output value')
    ylabel('counts')
    
    [val1,lBC] = min(abs(c-(croissantTh(1))));
    [val2,uBC] = min(abs(c-(croissantTh(2))));
    rangeC = c(lBC:uBC);
    rangeC = rangeC(1):0.001:rangeC(end);
    [val3,lBS] = min(abs(c-(slipperTh(1))));
    [val4,uBS] = min(abs(c-(slipperTh(2))));
    rangeS = c(lBS:uBS);
    rangeS = rangeS(1):0.001:rangeS(end);
    
    patch([rangeC(1),rangeC,rangeC(end)],[0.001,feval(FitFun,rangeC)',0.001],'red','FaceAlpha',0.1,'EdgeAlpha',0.1)
    patch([rangeS(1),rangeS,rangeS(end)],[0.001,feval(FitFun,rangeS)',0.001],'blue','FaceAlpha',0.1,'EdgeAlpha',0.1)
    
    set(gca, 'YScale', 'log')
    ylim([1,2000])
    yticks([1 10 100 1000])
    
    collectionAll = zeros([numel(velocities)-1,2]);
    
    if 1%numel(collectionImgsNNans) == 0
        disp('init');
        
        for idx = 1:numel(foldernames)
            count = 0;
            foldername = foldernames{idx};
            subfolders = dir(strcat(path,'\',foldername));
            subfolders = {subfolders.name};
            subfolders = subfolders(3:end);
            disp(foldername)
            for jdx = 1:numel(subfolders)
                imgCont = dir(strcat(path,'\',foldername,'\',subfolders{jdx}));
                imgCont = {imgCont.name};
                imgCont = imgCont(3:end);
                
                for kdx = 1:numel(imgCont)
                    fname = imgCont{kdx};
                    fpath = strcat(path,'\',foldername,'\',subfolders{jdx},'\',fname);
                    I = imread(fpath);
                    I = im2double(I);
                    I = I.*winImg;
                    I = imadjust(I);
                    I = im2uint8(I);
                    NNans = predict(net,I);
                    collectionImgsNNans{end+1,1} = I;
                    collectionImgsNNans{end,2} = NNans;
                    collectionImgsNNans{end,3} = idx;
                    if (NNans >= croissantTh(1)) && (NNans <= croissantTh(2))
                        collectionAll(idx,1) = collectionAll(idx,1) + 1;
                        count = count + 1;
                    elseif (NNans >= slipperTh(1)) && (NNans <= slipperTh(2))
                        collectionAll(idx,2) = collectionAll(idx,2) + 1;
                        count = count + 1;
                    else
                        count = count + 1;
                        continue
                    end
                end
            end
            
            collectionAll(idx,:) = collectionAll(idx,:)./count;
            
        end
    end
    
    collectionAll = [[0,0] ; collectionAll];
    
    figure(fig)
    subplot(ndxMax,2,2*ndx)
    
    axes = gca;
    
    xlabel('velocity [mm/s]')
    ylabel('fraction of cell shapes')
    A = patch([velocities,velocities(end)],[slippersMan,0],[0,0,1],'FaceAlpha',0.1,'EdgeAlpha',0.1);
    hold on
    B = patch([velocities,velocities(end)],[croissantsMan,0],[1,0,0],'FaceAlpha',0.1,'EdgeAlpha',0.1);
    
    C = plot(velocities,croissantsMan,'Color',[1,0,0],'LineStyle','-','Marker','none','DisplayName','Croissant (man)');
    D = plot(velocities,slippersMan,'Color',[0,0,1],'LineStyle','-','Marker','none','DisplayName','Slipper (man)');
    
    F = plot(velocities,collectionAll(:,1),'Color',[1,0,0],'LineStyle','-.','Marker','none','DisplayName','Croissant (CNN)');
    G = plot(velocities,collectionAll(:,2),'Color',[0,0,1],'LineStyle','-.','Marker','none','DisplayName','Slipper (CNN)');
    
    if 0
        L = legend([C,D,F,G],'Location','east');
        set(fig.Children(1),'Interpreter','latex');
        set(fig.Children(2),'TickLabelInterpreter','latex');
    end
    
    if ndx == 3
        txt = strcat(txtRight(ndx),' adapted threshold ranges');
    else
        txt = strcat(txtRight(ndx),' threshold = ',num2str(sigma),'$$\sigma$$');
    end
    
    
    text(0.5,0.9,txt,'HorizontalAlignment','left')
    
    grid on
    set(axes.YLabel,'Interpreter','latex');
    set(axes.XLabel,'Interpreter','latex');
    xlim([0,10])
    box on
    
end





